"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.descriptor_pb2
import google.protobuf.internal.extension_dict
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class MapKeySpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    PATTERN_FIELD_NUMBER: builtins.int
    LENGTH_FIELD_NUMBER: builtins.int
    value: builtins.str
    pattern: builtins.str
    length: builtins.str
    def __init__(
        self,
        *,
        value: builtins.str = ...,
        pattern: builtins.str = ...,
        length: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["length", b"length", "pattern", b"pattern", "value", b"value"]) -> None: ...

global___MapKeySpec = MapKeySpec

EXACTLY_ONE_FIELD_NUMBER: builtins.int
REQUIRED_FIELD_NUMBER: builtins.int
PATTERN_FIELD_NUMBER: builtins.int
VALUE_FIELD_NUMBER: builtins.int
SIZE_FIELD_NUMBER: builtins.int
LENGTH_FIELD_NUMBER: builtins.int
UNIQUE_FIELD_NUMBER: builtins.int
MAP_KEY_FIELD_NUMBER: builtins.int
BYTES_FIELD_NUMBER: builtins.int
exactly_one: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.OneofOptions, builtins.bool]
required: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.bool]
pattern: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.str]
value: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.str]
size: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.str]
length: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.str]
unique: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.bool]
map_key: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, global___MapKeySpec]
bytes: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.str]



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.ai.foundation_models.v1.text_common_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class CompletionRequest(google.protobuf.message.Message):
    """Request for the service to generate text completion."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_URI_FIELD_NUMBER: builtins.int
    COMPLETION_OPTIONS_FIELD_NUMBER: builtins.int
    MESSAGES_FIELD_NUMBER: builtins.int
    model_uri: builtins.str
    """The [ID of the model](/docs/foundation-models/concepts/yandexgpt/models) to be used for completion generation."""
    @property
    def completion_options(self) -> yandex.cloud.ai.foundation_models.v1.text_common_pb2.CompletionOptions:
        """Configuration options for completion generation."""

    @property
    def messages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.ai.foundation_models.v1.text_common_pb2.Message]:
        """A list of messages representing the context for the completion model."""

    def __init__(
        self,
        *,
        model_uri: builtins.str = ...,
        completion_options: yandex.cloud.ai.foundation_models.v1.text_common_pb2.CompletionOptions | None = ...,
        messages: collections.abc.Iterable[yandex.cloud.ai.foundation_models.v1.text_common_pb2.Message] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["completion_options", b"completion_options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["completion_options", b"completion_options", "messages", b"messages", "model_uri", b"model_uri"]) -> None: ...

global___CompletionRequest = CompletionRequest

@typing.final
class CompletionResponse(google.protobuf.message.Message):
    """Response containing generated text completions."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALTERNATIVES_FIELD_NUMBER: builtins.int
    USAGE_FIELD_NUMBER: builtins.int
    MODEL_VERSION_FIELD_NUMBER: builtins.int
    model_version: builtins.str
    """The model version changes with each new releases."""
    @property
    def alternatives(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.ai.foundation_models.v1.text_common_pb2.Alternative]:
        """A list of generated completion alternatives."""

    @property
    def usage(self) -> yandex.cloud.ai.foundation_models.v1.text_common_pb2.ContentUsage:
        """A set of statistics describing the number of content tokens used by the completion model."""

    def __init__(
        self,
        *,
        alternatives: collections.abc.Iterable[yandex.cloud.ai.foundation_models.v1.text_common_pb2.Alternative] | None = ...,
        usage: yandex.cloud.ai.foundation_models.v1.text_common_pb2.ContentUsage | None = ...,
        model_version: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["usage", b"usage"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["alternatives", b"alternatives", "model_version", b"model_version", "usage", b"usage"]) -> None: ...

global___CompletionResponse = CompletionResponse

@typing.final
class TokenizeRequest(google.protobuf.message.Message):
    """Request for the service to tokenize input text."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_URI_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    model_uri: builtins.str
    """The identifier of the model to be used for tokenization."""
    text: builtins.str
    """Text to be tokenized."""
    def __init__(
        self,
        *,
        model_uri: builtins.str = ...,
        text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["model_uri", b"model_uri", "text", b"text"]) -> None: ...

global___TokenizeRequest = TokenizeRequest

@typing.final
class TokenizeResponse(google.protobuf.message.Message):
    """Response containing tokenized content from request."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOKENS_FIELD_NUMBER: builtins.int
    MODEL_VERSION_FIELD_NUMBER: builtins.int
    model_version: builtins.str
    """Model version (changes with model releases)."""
    @property
    def tokens(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.ai.foundation_models.v1.text_common_pb2.Token]:
        """A list of tokens obtained from tokenization."""

    def __init__(
        self,
        *,
        tokens: collections.abc.Iterable[yandex.cloud.ai.foundation_models.v1.text_common_pb2.Token] | None = ...,
        model_version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["model_version", b"model_version", "tokens", b"tokens"]) -> None: ...

global___TokenizeResponse = TokenizeResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.datatransfer.v1.endpoint_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetEndpointRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENDPOINT_ID_FIELD_NUMBER: builtins.int
    endpoint_id: builtins.str
    def __init__(
        self,
        *,
        endpoint_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["endpoint_id", b"endpoint_id"]) -> None: ...

global___GetEndpointRequest = GetEndpointRequest

@typing.final
class ListEndpointsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """Identifier of the folder containing the endpoints to be listed."""
    page_size: builtins.int
    """The maximum number of endpoints to be sent in the response message. If the
    folder contains more endpoints than `page_size`, `next_page_token` will be
    included
    in the response message. Include it into the subsequent `ListEndpointRequest` to
    fetch the next page. Defaults to `100` if not specified. The maximum allowed
    value
    for this field is `500`.
    """
    page_token: builtins.str
    """Opaque value identifying the endpoints page to be fetched. Should be empty in
    the first `ListEndpointsRequest`. Subsequent requests should have this field
    filled
    with the `next_page_token` from the previous `ListEndpointsResponse`.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListEndpointsRequest = ListEndpointsRequest

@typing.final
class ListEndpointsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENDPOINTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Opaque value identifying the next endpoints page. This field is empty if there
    are no more endpoints in the folder. Otherwise, it is non-empty and should be
    included in the subsequent `ListEndpointsRequest` to fetch the next endpoints
    page.
    """
    @property
    def endpoints(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.datatransfer.v1.endpoint_pb2.Endpoint]:
        """The list of endpoints. If there are more endpoints in the folder, then
        `next_page_token` is a non-empty string to be included into the subsequent
        `ListEndpointsRequest` to fetch the next endpoints page.
        """

    def __init__(
        self,
        *,
        endpoints: collections.abc.Iterable[yandex.cloud.datatransfer.v1.endpoint_pb2.Endpoint] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["endpoints", b"endpoints", "next_page_token", b"next_page_token"]) -> None: ...

global___ListEndpointsResponse = ListEndpointsResponse

@typing.final
class CreateEndpointRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    SETTINGS_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    name: builtins.str
    description: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def settings(self) -> yandex.cloud.datatransfer.v1.endpoint_pb2.EndpointSettings: ...
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        settings: yandex.cloud.datatransfer.v1.endpoint_pb2.EndpointSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["settings", b"settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "folder_id", b"folder_id", "labels", b"labels", "name", b"name", "settings", b"settings"]) -> None: ...

global___CreateEndpointRequest = CreateEndpointRequest

@typing.final
class CreateEndpointMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENDPOINT_ID_FIELD_NUMBER: builtins.int
    endpoint_id: builtins.str
    def __init__(
        self,
        *,
        endpoint_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["endpoint_id", b"endpoint_id"]) -> None: ...

global___CreateEndpointMetadata = CreateEndpointMetadata

@typing.final
class UpdateEndpointRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ENDPOINT_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    SETTINGS_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    endpoint_id: builtins.str
    """Identifier of the endpoint to be updated."""
    name: builtins.str
    """The new endpoint name. Must be unique within the folder."""
    description: builtins.str
    """The new description for the endpoint."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def settings(self) -> yandex.cloud.datatransfer.v1.endpoint_pb2.EndpointSettings:
        """The new endpoint name. Must be unique within the folder."""

    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask specifying endpoint fields to be updated. Semantics for this field is
        described here:
        <https://pkg.go.dev/google.golang.org/protobuf/types/known/fieldmaskpb#FieldMask>
        The only exception: if the repeated field is specified in the mask, then
        the new value replaces the old one instead of being appended to the old one.
        """

    def __init__(
        self,
        *,
        endpoint_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        settings: yandex.cloud.datatransfer.v1.endpoint_pb2.EndpointSettings | None = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["settings", b"settings", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "endpoint_id", b"endpoint_id", "labels", b"labels", "name", b"name", "settings", b"settings", "update_mask", b"update_mask"]) -> None: ...

global___UpdateEndpointRequest = UpdateEndpointRequest

@typing.final
class UpdateEndpointMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENDPOINT_ID_FIELD_NUMBER: builtins.int
    endpoint_id: builtins.str
    def __init__(
        self,
        *,
        endpoint_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["endpoint_id", b"endpoint_id"]) -> None: ...

global___UpdateEndpointMetadata = UpdateEndpointMetadata

@typing.final
class DeleteEndpointRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENDPOINT_ID_FIELD_NUMBER: builtins.int
    endpoint_id: builtins.str
    def __init__(
        self,
        *,
        endpoint_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["endpoint_id", b"endpoint_id"]) -> None: ...

global___DeleteEndpointRequest = DeleteEndpointRequest

@typing.final
class DeleteEndpointMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENDPOINT_ID_FIELD_NUMBER: builtins.int
    endpoint_id: builtins.str
    def __init__(
        self,
        *,
        endpoint_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["endpoint_id", b"endpoint_id"]) -> None: ...

global___DeleteEndpointMetadata = DeleteEndpointMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ResourcePreset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    CORES_FIELD_NUMBER: builtins.int
    MEMORY_FIELD_NUMBER: builtins.int
    id: builtins.str
    cores: builtins.int
    memory: builtins.int
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        cores: builtins.int = ...,
        memory: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cores", b"cores", "id", b"id", "memory", b"memory"]) -> None: ...

global___ResourcePreset = ResourcePreset



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing
import yandex.cloud.certificatemanager.v1.certificate_pb2
import yandex.cloud.operation.operation_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _CertificateView:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CertificateViewEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CertificateView.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    BASIC: _CertificateView.ValueType  # 0
    """Output basic information about the certificate."""
    FULL: _CertificateView.ValueType  # 1
    """Output full information about the certificate including domain challenges."""

class CertificateView(_CertificateView, metaclass=_CertificateViewEnumTypeWrapper): ...

BASIC: CertificateView.ValueType  # 0
"""Output basic information about the certificate."""
FULL: CertificateView.ValueType  # 1
"""Output full information about the certificate including domain challenges."""
global___CertificateView = CertificateView

@typing.final
class GetCertificateRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERTIFICATE_ID_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    certificate_id: builtins.str
    """ID of the certificate to return.

    To get the ID of a certificate use a [CertificateService.List] request.
    """
    view: global___CertificateView.ValueType
    """The output type of the certificate."""
    def __init__(
        self,
        *,
        certificate_id: builtins.str = ...,
        view: global___CertificateView.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["certificate_id", b"certificate_id", "view", b"view"]) -> None: ...

global___GetCertificateRequest = GetCertificateRequest

@typing.final
class ListCertificatesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list certificate in."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than `page_size`, the service returns a [ListCertificatesResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListCertificatesResponse.next_page_token] returned by a previous list request.
    """
    view: global___CertificateView.ValueType
    """The output type of the certificate."""
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        view: global___CertificateView.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token", "view", b"view"]) -> None: ...

global___ListCertificatesRequest = ListCertificatesRequest

@typing.final
class ListCertificatesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERTIFICATES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number
    of results is greater than the specified [ListCertificatesRequest.page_size], use
    the `next_page_token` as the value for the [ListCertificatesRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def certificates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.certificatemanager.v1.certificate_pb2.Certificate]:
        """List of certificates in the specified folder."""

    def __init__(
        self,
        *,
        certificates: collections.abc.Iterable[yandex.cloud.certificatemanager.v1.certificate_pb2.Certificate] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["certificates", b"certificates", "next_page_token", b"next_page_token"]) -> None: ...

global___ListCertificatesResponse = ListCertificatesResponse

@typing.final
class ListVersionsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERTIFICATE_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    certificate_id: builtins.str
    """ID of the certificate to list versions for."""
    page_size: builtins.int
    """Page token. To get the next page of results, set `page_token` to the
    [ListCertificatesResponse.next_page_token] returned by a previous list request.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListCertificatesResponse.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        certificate_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["certificate_id", b"certificate_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListVersionsRequest = ListVersionsRequest

@typing.final
class ListVersionsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number
    of results is greater than the specified [ListCertificatesRequest.page_size], use
    the `next_page_token` as the value for the [ListCertificatesRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def versions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.certificatemanager.v1.certificate_pb2.Version]:
        """List of versions for the specified certificate."""

    def __init__(
        self,
        *,
        versions: collections.abc.Iterable[yandex.cloud.certificatemanager.v1.certificate_pb2.Version] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "versions", b"versions"]) -> None: ...

global___ListVersionsResponse = ListVersionsResponse

@typing.final
class CreateCertificateRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    CERTIFICATE_FIELD_NUMBER: builtins.int
    CHAIN_FIELD_NUMBER: builtins.int
    PRIVATE_KEY_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create a certificate in."""
    name: builtins.str
    """Name of the certificate.
    The name must be unique within the folder.
    """
    description: builtins.str
    """Description of the certificate."""
    certificate: builtins.str
    """PEM-encoded certificate content of the certificate."""
    chain: builtins.str
    """PEM-encoded certificate chain content of the certificate."""
    private_key: builtins.str
    """PEM-encoded private key content of the certificate."""
    deletion_protection: builtins.bool
    """Flag that protects deletion of the certificate"""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Labels for the certificate as `key:value` pairs."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        certificate: builtins.str = ...,
        chain: builtins.str = ...,
        private_key: builtins.str = ...,
        deletion_protection: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["certificate", b"certificate", "chain", b"chain", "deletion_protection", b"deletion_protection", "description", b"description", "folder_id", b"folder_id", "labels", b"labels", "name", b"name", "private_key", b"private_key"]) -> None: ...

global___CreateCertificateRequest = CreateCertificateRequest

@typing.final
class CreateCertificateMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERTIFICATE_ID_FIELD_NUMBER: builtins.int
    certificate_id: builtins.str
    """ID of the certificate being created."""
    def __init__(
        self,
        *,
        certificate_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["certificate_id", b"certificate_id"]) -> None: ...

global___CreateCertificateMetadata = CreateCertificateMetadata

@typing.final
class UpdateCertificateRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    CERTIFICATE_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    CERTIFICATE_FIELD_NUMBER: builtins.int
    CHAIN_FIELD_NUMBER: builtins.int
    PRIVATE_KEY_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    certificate_id: builtins.str
    """ID of the certificate to update.
    To get the ID of a certificate use a [CertificateService.List] request.
    """
    name: builtins.str
    """New name for the certificate."""
    description: builtins.str
    """New description for the certificate."""
    certificate: builtins.str
    """New PEM-encoded certificate content for the certificate. Used only for imported certificates."""
    chain: builtins.str
    """New PEM-encoded certificate chain content for the certificate. Used only for imported certificates."""
    private_key: builtins.str
    """New PEM-encoded private key content for the certificate. Used only for imported certificates."""
    deletion_protection: builtins.bool
    """Flag that protects deletion of the certificate"""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which attributes of the certificate are going to be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """New labels for the certificate as `key:value` pairs."""

    def __init__(
        self,
        *,
        certificate_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        certificate: builtins.str = ...,
        chain: builtins.str = ...,
        private_key: builtins.str = ...,
        deletion_protection: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["certificate", b"certificate", "certificate_id", b"certificate_id", "chain", b"chain", "deletion_protection", b"deletion_protection", "description", b"description", "labels", b"labels", "name", b"name", "private_key", b"private_key", "update_mask", b"update_mask"]) -> None: ...

global___UpdateCertificateRequest = UpdateCertificateRequest

@typing.final
class UpdateCertificateMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERTIFICATE_ID_FIELD_NUMBER: builtins.int
    certificate_id: builtins.str
    """ID of the certificate being updated."""
    def __init__(
        self,
        *,
        certificate_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["certificate_id", b"certificate_id"]) -> None: ...

global___UpdateCertificateMetadata = UpdateCertificateMetadata

@typing.final
class DeleteCertificateRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERTIFICATE_ID_FIELD_NUMBER: builtins.int
    certificate_id: builtins.str
    """ID of the certificate to be deleted."""
    def __init__(
        self,
        *,
        certificate_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["certificate_id", b"certificate_id"]) -> None: ...

global___DeleteCertificateRequest = DeleteCertificateRequest

@typing.final
class DeleteCertificateMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERTIFICATE_ID_FIELD_NUMBER: builtins.int
    certificate_id: builtins.str
    """ID of the certificate being deleted."""
    def __init__(
        self,
        *,
        certificate_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["certificate_id", b"certificate_id"]) -> None: ...

global___DeleteCertificateMetadata = DeleteCertificateMetadata

@typing.final
class RequestNewCertificateRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    DOMAINS_FIELD_NUMBER: builtins.int
    CHALLENGE_TYPE_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create a certificate in."""
    name: builtins.str
    """Name of the certificate."""
    description: builtins.str
    """Description of the certificate."""
    challenge_type: yandex.cloud.certificatemanager.v1.certificate_pb2.ChallengeType.ValueType
    """Type of the domain validation challenge."""
    deletion_protection: builtins.bool
    """Flag that protects deletion of the certificate"""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Labels for the certificate as `key:value` pairs."""

    @property
    def domains(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Fully qualified domain names of the certificate."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        domains: collections.abc.Iterable[builtins.str] | None = ...,
        challenge_type: yandex.cloud.certificatemanager.v1.certificate_pb2.ChallengeType.ValueType = ...,
        deletion_protection: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["challenge_type", b"challenge_type", "deletion_protection", b"deletion_protection", "description", b"description", "domains", b"domains", "folder_id", b"folder_id", "labels", b"labels", "name", b"name"]) -> None: ...

global___RequestNewCertificateRequest = RequestNewCertificateRequest

@typing.final
class RequestNewCertificateMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERTIFICATE_ID_FIELD_NUMBER: builtins.int
    certificate_id: builtins.str
    """ID of the certificate that is being requested."""
    def __init__(
        self,
        *,
        certificate_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["certificate_id", b"certificate_id"]) -> None: ...

global___RequestNewCertificateMetadata = RequestNewCertificateMetadata

@typing.final
class ListCertificateOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERTIFICATE_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    certificate_id: builtins.str
    """ID of the certificate to list operations for.

    To get the certificate ID, use a [CertificateService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page that should be returned. If the number of available
    results is larger than `page_size`, the service returns a [ListCertificateOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListCertificateOperationsResponse.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        certificate_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["certificate_id", b"certificate_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListCertificateOperationsRequest = ListCertificateOperationsRequest

@typing.final
class ListCertificateOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListCertificateOperationsRequest.page_size], use the `next_page_token` as the value
    for the [ListCertificateOperationsRequest.page_token] query parameter in the next list request.
    Each subsequent list request will have its own [next_page_token] to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified certificate."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListCertificateOperationsResponse = ListCertificateOperationsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Backup(google.protobuf.message.Message):
    """An SQL Server backup resource.

    For more information, see the [Backup](/docs/managed-sqlserver/concepts/backup) section in the documentation.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    SOURCE_CLUSTER_ID_FIELD_NUMBER: builtins.int
    STARTED_AT_FIELD_NUMBER: builtins.int
    DATABASES_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the backup."""
    folder_id: builtins.str
    """ID of the folder that the backup belongs to."""
    source_cluster_id: builtins.str
    """ID of the SQL Server cluster that the backup was created for."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time when the backup operation was completed."""

    @property
    def started_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time when the backup operation was started."""

    @property
    def databases(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of databases included in the backup."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        source_cluster_id: builtins.str = ...,
        started_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        databases: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "started_at", b"started_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "databases", b"databases", "folder_id", b"folder_id", "id", b"id", "source_cluster_id", b"source_cluster_id", "started_at", b"started_at"]) -> None: ...

global___Backup = Backup



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/loadtesting/api/v1/test/single_agent_configuration.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.loadtesting.api.v1.test import agent_selector_pb2 as yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_test_dot_agent__selector__pb2
from yandex.cloud.loadtesting.api.v1.test import file_pointer_pb2 as yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_test_dot_file__pointer__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEyandex/cloud/loadtesting/api/v1/test/single_agent_configuration.proto\x12$yandex.cloud.loadtesting.api.v1.test\x1a\x39yandex/cloud/loadtesting/api/v1/test/agent_selector.proto\x1a\x37yandex/cloud/loadtesting/api/v1/test/file_pointer.proto\"\xb5\x02\n\x18SingleAgentConfiguration\x12\x11\n\tconfig_id\x18\x01 \x01(\t\x12K\n\x0e\x61gent_selector\x18\x02 \x01(\x0b\x32\x33.yandex.cloud.loadtesting.api.v1.test.AgentSelector\x12X\n\x05\x66iles\x18\x03 \x03(\x0b\x32I.yandex.cloud.loadtesting.api.v1.test.SingleAgentConfiguration.FilesEntry\x1a_\n\nFilesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12@\n\x05value\x18\x02 \x01(\x0b\x32\x31.yandex.cloud.loadtesting.api.v1.test.FilePointer:\x02\x38\x01\x42y\n(yandex.cloud.api.loadtesting.api.v1.testZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/test;testb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.loadtesting.api.v1.test.single_agent_configuration_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(yandex.cloud.api.loadtesting.api.v1.testZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/test;test'
  _SINGLEAGENTCONFIGURATION_FILESENTRY._options = None
  _SINGLEAGENTCONFIGURATION_FILESENTRY._serialized_options = b'8\001'
  _globals['_SINGLEAGENTCONFIGURATION']._serialized_start=228
  _globals['_SINGLEAGENTCONFIGURATION']._serialized_end=537
  _globals['_SINGLEAGENTCONFIGURATION_FILESENTRY']._serialized_start=442
  _globals['_SINGLEAGENTCONFIGURATION_FILESENTRY']._serialized_end=537
# @@protoc_insertion_point(module_scope)
